@@ -12,14 +12,15 @@ import shutil as _shutil
 
 
 def shread(filename, lmax=None, error=False, header=False, header2=False,
-           skip=0):
+           skip=0, encoding=None):
     """
     Read shtools-formatted spherical harmonic coefficients from a text file.
 
     Usage
     -----
     coeffs, [errors], lmaxout, [header], [header2] = shread(
-        filename, [error=True, header=True, header2=True, lmax, skip])
+        filename, [error=True, header=True, header2=True, lmax, skip,
+        encoding])
 
     Returns
     -------
@@ -57,6 +58,8 @@ def shread(filename, lmax=None, error=False, header=False, header2=False,
         the start of the spherical harmonic coefficients.
     skip : int, optional, default = 0
         The number of lines to skip before parsing the file.
+    encoding : str, optional, default = None
+        Encoding of the input file. The default is to use the system default.
 
     Notes
     -----
@@ -170,15 +173,17 @@ def shread(filename, lmax=None, error=False, header=False, header2=False,
     # open file, skip lines, read header, determine lstart, and then read
     # coefficients one line at a time
     if _isurl(filename):
+        if encoding is not None:
+            _response.encoding = encoding
         f = _io.StringIO(_response.text)
         if filename[-4:] == '.zip':
-            f = _io.TextIOWrapper(zf.open(zf.namelist()[0]))
+            f = _io.TextIOWrapper(zf.open(zf.namelist()[0]), encoding=encoding)
     elif filename[-3:] == '.gz':
-        f = _gzip.open(filename, mode='rt')
+        f = _gzip.open(filename, mode='rt', encoding=encoding)
     elif filename[-4:] == '.zip':
-        f = _io.TextIOWrapper(zf.open(zf.namelist()[0]))
+        f = _io.TextIOWrapper(zf.open(zf.namelist()[0]), encoding=encoding)
     else:
-        f = open(filename, 'r')
+        f = open(filename, 'r', encoding=encoding)
 
     with f:
         if skip != 0:
@@ -238,12 +243,13 @@ def shread(filename, lmax=None, error=False, header=False, header2=False,
                 errors = _np.zeros((2, lmaxout+1, lmaxout+1))
         except ValueError:
             try:
-                num = complex(line.split()[2])  # noqa F841
-                coeffs = _np.zeros((2, lmaxout+1, lmaxout+1), dtype=complex)
+                num = _np.complex128(line.split()[2])  # noqa F841
+                coeffs = _np.zeros((2, lmaxout+1, lmaxout+1),
+                                   dtype=_np.complex128)
                 kind = 'complex'
                 if error is True:
                     errors = _np.zeros((2, lmaxout+1, lmaxout+1),
-                                       dtype=complex)
+                                       dtype=_np.complex128)
             except ValueError:
                 raise ValueError('Coefficients can not be converted to '
                                  'either float or complex. Coefficient '
@@ -278,13 +284,13 @@ def shread(filename, lmax=None, error=False, header=False, header2=False,
                                        .format(degree, order, l, m))
 
                 if kind == 'real':
-                    coeffs[0, l, m] = float(line.split()[2])
+                    coeffs[0, l, m] = _np.float64(line.split()[2])
                     if m > 0:
-                        coeffs[1, l, m] = float(line.split()[3])
+                        coeffs[1, l, m] = _np.float64(line.split()[3])
                 else:
-                    coeffs[0, l, m] = complex(line.split()[2])
+                    coeffs[0, l, m] = _np.complex128(line.split()[2])
                     if m > 0:
-                        coeffs[1, l, m] = complex(line.split()[3])
+                        coeffs[1, l, m] = _np.complex128(line.split()[3])
 
                 if error:
                     if len(line.split()) < 6:
@@ -294,11 +300,11 @@ def shread(filename, lmax=None, error=False, header=False, header2=False,
                                            'Last line is: {:s}'.format(line))
 
                     if kind == 'real':
-                        errors[0, l, m] = float(line.split()[4])
-                        errors[1, l, m] = float(line.split()[5])
+                        errors[0, l, m] = _np.float64(line.split()[4])
+                        errors[1, l, m] = _np.float64(line.split()[5])
                     else:
-                        errors[0, l, m] = complex(line.split()[4])
-                        errors[1, l, m] = complex(line.split()[5])
+                        errors[0, l, m] = _np.complex128(line.split()[4])
+                        errors[1, l, m] = _np.complex128(line.split()[5])
 
     if error is True and header is True:
         if header2:
@@ -317,13 +323,13 @@ def shread(filename, lmax=None, error=False, header=False, header2=False,
 
 
 def shwrite(filename, coeffs, errors=None, header=None, header2=None,
-            lmax=None):
+            lmax=None, encoding=None):
     """
     Write shtools-formatted spherical harmonic coefficients to a text file.
 
     Usage
     -----
-    shwrite(filename, coeffs, [errors, header, header2, lmax])
+    shwrite(filename, coeffs, [errors, header, header2, lmax, encoding])
 
     Parameters
     ----------
@@ -343,6 +349,8 @@ def shwrite(filename, coeffs, errors=None, header=None, header2=None,
         coefficients.
     lmax : int, optional, default = None
         The maximum spherical harmonic degree to write to the file.
+    encoding : str, optional, default = None
+        Encoding of the output file. The default is to use the system default.
 
     Notes
     -----
@@ -380,7 +388,7 @@ def shwrite(filename, coeffs, errors=None, header=None, header2=None,
     else:
         filebase = filename
 
-    with open(filebase, mode='w') as file:
+    with open(filebase, mode='w', encoding=encoding) as file:
         if header is not None:
             file.write(header + '\n')
         if header2 is not None:
